@@ -1,3 +1,13 @@
+# Type Flags
+TYPE_UNDEFINED = 0
+TYPE_INT = 1
+TYPE_LONG_LONG = 2
+TYPE_FLOAT = 3
+TYPE_DOUBLE = 4
+TYPE_CHAR = 5
+
+
+# KTB Class
 class ktb:
     readme_size = 0
     readme_content = ""
